pub struct InspectedDeclaration {
pub name: String,
pub value: CssValue,
pub important: bool,
pub applied: bool,
}Expand description
One property declaration as shown in the Styles panel.
Fields
name: Stringvalue: CssValueimportant: boolapplied: boolWhether this declaration is the cascade winner for its property.